@@ -15,7 +15,7 @@ namespace Botan {
 /**
 * MD5
 */
-class BOTAN_DLL MD5 : public MDx_HashFunction
+class BOTAN_DLL MD5 final : public MDx_HashFunction
    {
    public:
       std::string name() const override { return "MD5"; }
@@ -24,21 +24,22 @@ class BOTAN_DLL MD5 : public MDx_HashFunction
 
       void clear() override;
 
-      MD5() : MDx_HashFunction(64, false, true), M(16), digest(4)
+      MD5() : MDx_HashFunction(64, false, true), m_M(16), m_digest(4)
          { clear(); }
    protected:
       void compress_n(const byte[], size_t blocks) override;
       void copy_out(byte[]) override;
 
+   private:
       /**
-      * The message buffer, exposed for use by subclasses (x86 asm)
+      * The message buffer
       */
-      secure_vector<u32bit> M;
+      secure_vector<u32bit> m_M;
 
       /**
-      * The digest value, exposed for use by subclasses (x86 asm)
+      * The digest value
       */
-      secure_vector<u32bit> digest;
+      secure_vector<u32bit> m_digest;
    };
 
 }
