@@ -15,7 +15,7 @@ namespace Botan {
 /**
 * PRF from ANSI X9.42
 */
-class BOTAN_DLL X942_PRF : public KDF
+class BOTAN_DLL X942_PRF final : public KDF
    {
    public:
       std::string name() const override { return "X942_PRF(" + m_key_wrap_oid + ")"; }
@@ -26,7 +26,7 @@ class BOTAN_DLL X942_PRF : public KDF
                  const byte secret[], size_t secret_len,
                  const byte salt[], size_t salt_len) const override;
 
-      X942_PRF(const std::string& oid);
+      explicit X942_PRF(const std::string& oid);
    private:
       std::string m_key_wrap_oid;
    };
